@@ -1,5 +1,5 @@
 from base import RESTModel
-
+import json
 
 class Application(RESTModel):
     """Represents a Tutum Application object"""
@@ -22,6 +22,14 @@ class Application(RESTModel):
         """
         return self._perform_action("stop")
 
+    def redeploy(self, tag=None):
+        """Redeploy the application in Tutum.
+
+        :returns: bool -- whether or not the operation succeeded
+        :raises: TutumApiError
+        """
+        return self._perform_action("redeploy", data=json.dumps({"tag": tag}))
+
     @property
     def logs(self):
         """Fetches and returns the logs for the application from Tutum
